eqcorrscan.utils.catalog\_to\_dd.compute\_differential\_times
=============================================================

.. currentmodule:: eqcorrscan.utils.catalog_to_dd

.. autofunction:: compute_differential_times